Index: channels/chan_zap.c
===================================================================
--- channels/chan_zap.c	(revision 103664)
+++ channels/chan_zap.c	(working copy)
@@ -6041,15 +6041,14 @@
 	return 0;
 }
 
-/*! enable or disable the chan_zap Do-Not-Disturb mode for a Zaptel channel
- * @zapchan "Physical" Zaptel channel (e.g: Zap/5)
- * @on: 1 to enable, 0 to disable
+/*! \brief enable or disable the chan_zap Do-Not-Disturb mode for a Zaptel channel
+ * \param zapchan "Physical" Zaptel channel (e.g: Zap/5)
+ * \param on 1 to enable, 0 to disable
  *
  * chan_zap has a DND (Do Not Disturb) mode for each zapchan (physical 
  * zaptel channel). Use this to enable or disable it.
  *
- * \fixme the use of the word "channel" for those zapchans is really
- * confusing.
+ * \bug the use of the word "channel" for those zapchans is really confusing.
  */
 static void zap_dnd(struct zt_pvt *zapchan, int on)
 {
Index: channels/chan_sip.c
===================================================================
--- channels/chan_sip.c	(revision 103664)
+++ channels/chan_sip.c	(working copy)
@@ -360,7 +360,7 @@
 /*! \brief States for outbound registrations (with register= lines in sip.conf */
 enum sipregistrystate {
 	REG_STATE_UNREGISTERED = 0,	/*!< We are not registred 
-		 *  \noteInitial state. We should have a timeout scheduled for the initial
+		 *  \note Initial state. We should have a timeout scheduled for the initial
 		 * (or next) registration transmission, calling sip_reregister
 		 */
 
@@ -580,7 +580,7 @@
 /*! \brief Standard SIP and TLS port from RFC 3261. DO NOT CHANGE THIS */
 #define STANDARD_SIP_PORT	5060
 #define STANDARD_TLS_PORT	5061
-/* Note: in many SIP headers, absence of a port number implies port 5060,
+/*! \note in many SIP headers, absence of a port number implies port 5060,
  * and this is why we cannot change the above constant.
  * There is a limited number of places in asterisk where we could,
  * in principle, use a different "default" port number, but
@@ -724,8 +724,8 @@
 
 /*@}*/ 
 
-/*! Object counters @{ 
- * \bug These counters are not handled in a thread-safe way.  ast_atomic_fetchadd_int()
+/*! \name Object counters @{
+ * \bug These counters are not handled in a thread-safe way ast_atomic_fetchadd_int()
  * should be used to modify these values. */
 static int suserobjs = 0;                /*!< Static users */
 static int ruserobjs = 0;                /*!< Realtime users */
@@ -1671,8 +1671,8 @@
 };
 
 /*---------------------------- Forward declarations of functions in chan_sip.c */
-/*! \note This is added to help splitting up chan_sip.c into several files
-	in coming releases */
+/* Note: This is added to help splitting up chan_sip.c into several files
+	in coming releases. */
 
 /*--- PBX interface functions */
 static struct ast_channel *sip_request_call(const char *type, int format, void *data, int *cause);
@@ -18477,7 +18477,8 @@
 
 
 /*! \brief Get Max or Min SE (session timer expiry)
-	\param max if true, get max se, otherwise min se
+ * \param p pointer to the SIP dialog 
+ * \param max if true, get max se, otherwise min se
 */
 int st_get_se(struct sip_pvt *p, int max)
 {
@@ -18528,7 +18529,7 @@
 
 
 /*! \brief Get the entity (UAC or UAS) that's acting as the session-timer refresher 
-	\param sip_pvt pointer to the SIP dialog 
+ * \param p pointer to the SIP dialog 
 */
 enum st_refresher st_get_refresher(struct sip_pvt *p)
 {
@@ -18557,7 +18558,7 @@
 
 
 /*! \brief Get the session-timer mode 
-	\param sip_pvt pointer to the SIP dialog 
+ * \param p pointer to the SIP dialog 
 */
 enum st_mode st_get_mode(struct sip_pvt *p)
 {
@@ -18769,12 +18770,14 @@
 }
 
 /*! \brief PBX interface function -build SIP pvt structure 
-	SIP calls initiated by the PBX arrive here 
-
-	SIP Dial string syntax
-		SIP/exten@host!dnid
-	or	SIP/host/exten!dnid
-	or	SIP/host!dnid
+ *	SIP calls initiated by the PBX arrive here. 
+ *
+ * \verbatim	
+ * 	SIP Dial string syntax
+ *		SIP/exten@host!dnid
+ *	or	SIP/host/exten!dnid
+ *	or	SIP/host!dnid
+ * \endverbatim
 */
 static struct ast_channel *sip_request_call(const char *type, int format, void *data, int *cause)
 {
Index: channels/misdn/isdn_msg_parser.c
===================================================================
--- channels/misdn/isdn_msg_parser.c	(revision 103664)
+++ channels/misdn/isdn_msg_parser.c	(working copy)
@@ -11,8 +11,8 @@
  * the GNU General Public License
  */
 
-/*! \file \brief
- * Interface to mISDN - message parser
+/*! \file 
+ * \brief Interface to mISDN - message parser
  * \author Christian Richter <crich@beronet.com>
  */
 
Index: channels/misdn/portinfo.c
===================================================================
--- channels/misdn/portinfo.c	(revision 103664)
+++ channels/misdn/portinfo.c	(working copy)
@@ -1,5 +1,5 @@
-/*! \file \brief
- * Interface to mISDN - ???
+/*! \file 
+ * \brief Interface to mISDN - port info
  * \author Christian Richter <crich@beronet.com>
  */
 
Index: channels/misdn/isdn_lib.c
===================================================================
--- channels/misdn/isdn_lib.c	(revision 103664)
+++ channels/misdn/isdn_lib.c	(working copy)
@@ -11,8 +11,8 @@
  * the GNU General Public License
  */
 
-/*! \file \brief
- * Interface to mISDN
+/*! \file 
+ * \brief Interface to mISDN
  * \author Christian Richter <crich@beronet.com>
  */
 
Index: channels/misdn/isdn_lib.h
===================================================================
--- channels/misdn/isdn_lib.h	(revision 103664)
+++ channels/misdn/isdn_lib.h	(working copy)
@@ -11,9 +11,8 @@
  * the GNU General Public License
  */
 
-/*! \file \brief
- * 
- * Interface to mISDN
+/*! \file 
+ * \brief Interface to mISDN
  *
  * \author Christian Richter <crich@beronet.com>
  */
Index: channels/misdn/chan_misdn_config.h
===================================================================
--- channels/misdn/chan_misdn_config.h	(revision 103664)
+++ channels/misdn/chan_misdn_config.h	(working copy)
@@ -11,8 +11,8 @@
  * the GNU General Public License
  */
 
-/*! \file \brief
- * Interface to mISDN - Config
+/*! \file 
+ * \brief Interface to mISDN - Config
  * \author Christian Richter <crich@beronet.com>
  */
 
Index: channels/misdn/ie.c
===================================================================
--- channels/misdn/ie.c	(revision 103664)
+++ channels/misdn/ie.c	(working copy)
@@ -15,8 +15,8 @@
  * the GNU General Public License
  */
 
-/*! \file \brief
- * Interface to mISDN
+/*! \file 
+ * \brief Interface to mISDN
  * \author Christian Richter <crich@beronet.com>
  */
 
Index: apps/app_queue.c
===================================================================
--- apps/app_queue.c	(revision 103664)
+++ apps/app_queue.c	(working copy)
@@ -2979,6 +3046,7 @@
  *
  * \param[in] qe the queue_ent structure which corresponds to the caller attempting to reach members
  * \param[in] options the options passed as the third parameter to the Queue() application
+ * \param[in] announceoverride filename to play to user when waiting 
  * \param[in] url the url passed as the fourth parameter to the Queue() application
  * \param[in,out] tries the number of times we have tried calling queue members
  * \param[out] noption set if the call to Queue() has the 'n' option set.
Index: include/asterisk/time.h
===================================================================
--- include/asterisk/time.h	(revision 103664)
+++ include/asterisk/time.h	(working copy)
@@ -57,8 +57,9 @@
 
 /*!
  * \brief Computes the difference (in microseconds) between two \c struct \c timeval instances.
- * \param end the end of the time period
- * \param start the beginning of the time period
+ * \param ast_tvdiff_sec 
+ * \arg end the end of the time period
+ * \arg start the beginning of the time period
  * \return the difference in microseconds
  */
 AST_INLINE_API(
Index: include/asterisk/strings.h
===================================================================
--- include/asterisk/strings.h	(revision 103664)
+++ include/asterisk/strings.h	(working copy)
@@ -148,16 +148,15 @@
 char *ast_strip_quoted(char *s, const char *beg_quotes, const char *end_quotes);
 
 /*!
-  \brief Strip backslash for "escaped" semicolons.
-  \brief s The string to be stripped (will be modified).
+  \brief Strip backslash for "escaped" semicolons, 
+	the string to be stripped (will be modified).
   \return The stripped string.
  */
 char *ast_unescape_semicolon(char *s);
 
 /*!
-  \brief Convert some C escape sequences (\b\f\n\r\t) into the
-	equivalent characters.
-  \brief s The string to be converted (will be modified).
+  \brief Convert some C escape sequences  \verbatim (\b\f\n\r\t) \endverbatim into the
+	equivalent characters. The string to be converted (will be modified).
   \return The converted string.
  */
 char *ast_unescape_c(char *s);
Index: include/asterisk/extconf.h
===================================================================
--- include/asterisk/extconf.h	(revision 103664)
+++ include/asterisk/extconf.h	(working copy)
@@ -15,8 +15,9 @@
  * the GNU General Public License Version 2. See the LICENSE file
  * at the top of the source tree.
  */
-/*! \file External configuration handlers (realtime and static configuration)
- *  \author Steve Murphy <murf@digium.com>
+/*! \file 
+ * \brief External configuration handlers (realtime and static configuration)
+ * \author Steve Murphy <murf@digium.com>
  *
  */
 
Index: main/config.c
===================================================================
--- main/config.c	(revision 103664)
+++ main/config.c	(working copy)
@@ -907,9 +907,11 @@
 }
 
 /*! \brief parse one line in the configuration.
+ * \verbatim
  * We can have a category header	[foo](...)
  * a directive				#include / #exec
  * or a regular line			name = value
+ * \endverbatim
  */
 static int process_text_line(struct ast_config *cfg, struct ast_category **cat,
 	char *buf, int lineno, const char *configfile, struct ast_flags flags,
Index: main/channel.c
===================================================================
--- main/channel.c	(revision 103664)
+++ main/channel.c	(working copy)
@@ -4059,7 +4059,10 @@
 }
 
 /*! \brief Send manager event for bridge link and unlink events.
-	\param type	1 for core, 2 for native
+ * \param onoff Link/Unlinked 
+ * \param type 1 for core, 2 for native
+ * \param c0 first channel in bridge
+ * \param c1 second channel in bridge
 */
 static void manager_bridge_event(int onoff, int type, struct ast_channel *c0, struct ast_channel *c1)
 {
Index: main/ast_expr2f.c
===================================================================
--- main/ast_expr2f.c	(revision 103664)
+++ main/ast_expr2f.c	(working copy)
@@ -1301,12 +1301,13 @@
 		} /* end of scanning one token */
 } /* end of ast_yylex */
 
-/* yy_get_next_buffer - try to read in a new buffer
+/*!
+ * \brief yy_get_next_buffer - try to read in a new buffer
  *
  * Returns a code representing an action:
- *	EOB_ACT_LAST_MATCH -
- *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
- *	EOB_ACT_END_OF_FILE - end of file
+ * \retval EOB_ACT_LAST_MATCH -
+ * \retval EOB_ACT_CONTINUE_SCAN - continue scanning from current position
+ * \retval EOB_ACT_END_OF_FILE - end of file
  */
 static int yy_get_next_buffer (yyscan_t yyscanner)
 {
@@ -1433,7 +1434,7 @@
 	return ret_val;
 }
 
-/* yy_get_previous_state - get the state just before the EOB char was reached */
+/*! \brief yy_get_previous_state - get the state just before the EOB char was reached */
 
     static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
 {
@@ -1463,7 +1464,7 @@
 	return yy_current_state;
 }
 
-/* yy_try_NUL_trans - try to make a transition on the NUL character
+/*! \brief yy_try_NUL_trans - try to make a transition on the NUL character.
  *
  * synopsis
  *	next_state = yy_try_NUL_trans( current_state );
@@ -1605,10 +1606,11 @@
 }
 #endif	/* ifndef YY_NO_INPUT */
 
-/** Immediately switch to a different input stream.
- * @param input_file A readable stream.
- * @param yyscanner The scanner object.
- * @note This function does not reset the start condition to @c INITIAL .
+/*!
+ * \brief Immediately switch to a different input stream.
+ * \param input_file A readable stream.
+ * \param yyscanner The scanner object.
+ * \note This function does not reset the start condition to @c INITIAL .
  */
     void ast_yyrestart  (FILE * input_file , yyscan_t yyscanner)
 {
@@ -1624,9 +1626,10 @@
 	ast_yy_load_buffer_state(yyscanner );
 }
 
-/** Switch to a different input buffer.
- * @param new_buffer The new input buffer.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Switch to a different input buffer.
+ * \param new_buffer The new input buffer.
+ * \param yyscanner The scanner object.
  */
     void ast_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
 {
@@ -1669,11 +1672,12 @@
 	yyg->yy_hold_char = *yyg->yy_c_buf_p;
 }
 
-/** Allocate and initialize an input buffer state.
- * @param file A readable stream.
- * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
- * @param yyscanner The scanner object.
- * @return the allocated buffer state.
+/*!
+ * \brief Allocate and initialize an input buffer state.
+ * \param file A readable stream.
+ * \param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
+ * \param yyscanner The scanner object.
+ * \return the allocated buffer state.
  */
     YY_BUFFER_STATE ast_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
 {
@@ -1699,9 +1703,10 @@
 	return b;
 }
 
-/** Destroy the buffer.
- * @param b a buffer created with ast_yy_create_buffer()
- * @param yyscanner The scanner object.
+/*! 
+ * \brief Destroy the buffer.
+ * \param b a buffer created with ast_yy_create_buffer()
+ * \param yyscanner The scanner object.
  */
     void ast_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
 {
@@ -1723,8 +1728,9 @@
 extern int isatty (int );
 #endif /* __cplusplus */
     
-/* Initializes or reinitializes a buffer.
- * This function is sometimes called more than once on the same buffer,
+/*! 
+ * \brief Initializes or reinitializes a buffer.
+ * \note This function is sometimes called more than once on the same buffer,
  * such as during a ast_yyrestart() or at EOF.
  */
     static void ast_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)
@@ -1752,9 +1758,10 @@
 	errno = oerrno;
 }
 
-/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
- * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
- * @param yyscanner The scanner object.
+/*! 
+ * \brief Discard all buffered characters. On the next scan, YY_INPUT will be called.
+ * \param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
+ * \param yyscanner The scanner object.
  */
     void ast_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
 {
@@ -1780,11 +1787,12 @@
 		ast_yy_load_buffer_state(yyscanner );
 }
 
-/** Pushes the new state onto the stack. The new state becomes
+/*!
+ * \brief Pushes the new state onto the stack. The new state becomes
  *  the current state. This function will allocate the stack
  *  if necessary.
- *  @param new_buffer The new state.
- *  @param yyscanner The scanner object.
+ *  \param new_buffer The new state.
+ *  \param yyscanner The scanner object.
  */
 void ast_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
 {
@@ -1813,9 +1821,10 @@
 	yyg->yy_did_buffer_switch_on_eof = 1;
 }
 
-/** Removes and deletes the top of the stack, if present.
+/*! 
+ * \brief Removes and deletes the top of the stack, if present.
  *  The next element becomes the new top.
- *  @param yyscanner The scanner object.
+ *  \param yyscanner The scanner object.
  */
 void ast_yypop_buffer_state (yyscan_t yyscanner)
 {
@@ -1877,11 +1886,12 @@
 	}
 }
 
-/** Setup the input buffer state to scan directly from a user-specified character buffer.
- * @param base the character buffer
- * @param size the size in bytes of the character buffer
- * @param yyscanner The scanner object.
- * @return the newly allocated buffer state object. 
+/*!
+ * \brief Setup the input buffer state to scan directly from a user-specified character buffer.
+ * \param base the character buffer
+ * \param size the size in bytes of the character buffer
+ * \param yyscanner The scanner object.
+ * \return the newly allocated buffer state object. 
  */
 YY_BUFFER_STATE ast_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
 {
@@ -1912,12 +1922,13 @@
 	return b;
 }
 
-/** Setup the input buffer state to scan a string. The next call to ast_yylex() will
- * scan from a @e copy of @a str.
- * @param str a NUL-terminated string to scan
- * @param yyscanner The scanner object.
- * @return the newly allocated buffer state object.
- * @note If you want to scan bytes that may contain NUL values, then use
+/*! 
+ * \brief Setup the input buffer state to scan a string. The next call to ast_yylex() will
+ * scan from a \e copy of \a str.
+ * \param yystr a NUL-terminated string to scan
+ * \param yyscanner The scanner object.
+ * \return the newly allocated buffer state object.
+ * \note If you want to scan bytes that may contain NUL values, then use
  *       ast_yy_scan_bytes() instead.
  */
 YY_BUFFER_STATE ast_yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
@@ -1926,12 +1937,13 @@
 	return ast_yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
 }
 
-/** Setup the input buffer state to scan the given bytes. The next call to ast_yylex() will
- * scan from a @e copy of @a bytes.
- * @param bytes the byte buffer to scan
- * @param len the number of bytes in the buffer pointed to by @a bytes.
- * @param yyscanner The scanner object.
- * @return the newly allocated buffer state object.
+/*! 
+ * \brief Setup the input buffer state to scan the given bytes. The next call to ast_yylex() will
+ * scan from a \e copy of \a bytes.
+ * \param yybytes the byte buffer to scan
+ * \param _yybytes_len the number of bytes in the buffer pointed to by \a bytes.
+ * \param yyscanner The scanner object.
+ * \return the newly allocated buffer state object.
  */
 YY_BUFFER_STATE ast_yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
 {
@@ -1992,8 +2004,9 @@
 
 /* Accessor  methods (get/set functions) to struct members. */
 
-/** Get the user-defined data for this scanner.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the user-defined data for this scanner.
+ * \param yyscanner The scanner object.
  */
 YY_EXTRA_TYPE ast_yyget_extra  (yyscan_t yyscanner)
 {
@@ -2001,8 +2014,9 @@
     return yyextra;
 }
 
-/** Get the current line number.
- * @param yyscanner The scanner object.
+/*! 
+ * \brief Get the current line number.
+ * \param yyscanner The scanner object.
  */
 int ast_yyget_lineno  (yyscan_t yyscanner)
 {
@@ -2014,8 +2028,9 @@
     return yylineno;
 }
 
-/** Get the current column number.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the current column number.
+ * \param yyscanner The scanner object.
  */
 int ast_yyget_column  (yyscan_t yyscanner)
 {
@@ -2027,8 +2042,9 @@
     return yycolumn;
 }
 
-/** Get the input stream.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the input stream.
+ * \param yyscanner The scanner object.
  */
 FILE *ast_yyget_in  (yyscan_t yyscanner)
 {
@@ -2036,8 +2052,9 @@
     return yyin;
 }
 
-/** Get the output stream.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the output stream.
+ * \param yyscanner The scanner object.
  */
 FILE *ast_yyget_out  (yyscan_t yyscanner)
 {
@@ -2045,8 +2062,9 @@
     return yyout;
 }
 
-/** Get the length of the current token.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the length of the current token.
+ * \param yyscanner The scanner object.
  */
 int ast_yyget_leng  (yyscan_t yyscanner)
 {
@@ -2054,8 +2072,9 @@
     return yyleng;
 }
 
-/** Get the current token.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Get the current token.
+ * \param yyscanner The scanner object.
  */
 
 char *ast_yyget_text  (yyscan_t yyscanner)
@@ -2064,9 +2083,10 @@
     return yytext;
 }
 
-/** Set the user-defined data. This data is never touched by the scanner.
- * @param user_defined The data to be associated with this scanner.
- * @param yyscanner The scanner object.
+/*!
+ * \brief Set the user-defined data. This data is never touched by the scanner.
+ * \param user_defined The data to be associated with this scanner.
+ * \param yyscanner The scanner object.
  */
 void ast_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
 {
@@ -2074,9 +2094,10 @@
     yyextra = user_defined ;
 }
 
-/** Set the current line number.
- * @param line_number
- * @param yyscanner The scanner object.
+/*!
+ * \brief Set the current line number.
+ * \param line_number
+ * \param yyscanner The scanner object.
  */
 void ast_yyset_lineno (int  line_number , yyscan_t yyscanner)
 {
@@ -2089,9 +2110,10 @@
     yylineno = line_number;
 }
 
-/** Set the current column.
- * @param line_number
- * @param yyscanner The scanner object.
+/*!
+ * \brief Set the current column.
+ * \param column_no
+ * \param yyscanner The scanner object.
  */
 void ast_yyset_column (int  column_no , yyscan_t yyscanner)
 {
@@ -2104,11 +2126,12 @@
     yycolumn = column_no;
 }
 
-/** Set the input stream. This does not discard the current
+/*!
+ * \brief Set the input stream. This does not discard the current
  * input buffer.
- * @param in_str A readable stream.
- * @param yyscanner The scanner object.
- * @see ast_yy_switch_to_buffer
+ * \param in_str A readable stream.
+ * \param yyscanner The scanner object.
+ * \see ast_yy_switch_to_buffer
  */
 void ast_yyset_in (FILE *  in_str , yyscan_t yyscanner)
 {
@@ -2162,9 +2185,10 @@
     
 /* User-visible API */
 
-/* ast_yylex_init is special because it creates the scanner itself, so it is
- * the ONLY reentrant function that doesn't take the scanner as the last argument.
- * That's why we explicitly handle the declaration, instead of using our macros.
+/*! \brief ast_yylex_init is special because it creates the scanner itself.
+ * 
+ * It is the ONLY reentrant function that doesn't take the scanner as the last argument.
+ * \note That's why we explicitly handle the declaration, instead of using our macros.
  */
 
 int ast_yylex_init(yyscan_t* ptr_yy_globals)
Index: res/res_config_curl.c
===================================================================
--- res/res_config_curl.c	(revision 103664)
+++ res/res_config_curl.c	(working copy)
@@ -277,8 +277,8 @@
 
 /*!
  * \brief Execute an INSERT query
- * \param database
- * \param table
+ * \param url
+ * \param unused
  * \param ap list containing one or more field/value set(s)
  *
  * Insert a new record into database table, prepare the sql statement.
Index: res/res_config_ldap.c
===================================================================
--- res/res_config_ldap.c	(revision 103664)
+++ res/res_config_ldap.c	(working copy)
@@ -652,7 +652,7 @@
 	return cbasedn;
 }
 
-/*! \brief Replace <search> by <by> in string. No check is done on string allocated size ! */
+/*! \brief Replace \<search\> by \<by\> in string. No check is done on string allocated size ! */
 static int replace_string_in_string(char *string, const char *search, const char *by)
 {
 	int search_len = strlen(search);
@@ -967,10 +967,12 @@
 
 /*! 
  * \brief Sorting alogrithm for qsort to find the order of the variables \a a and \a b
- * \param \a a pointer to category_and_metric struct
- * \param \a b pointer to category_and_metric struct
+ * \param a pointer to category_and_metric struct
+ * \param b pointer to category_and_metric struct
  *
- * \return the -1,0,1 (zero for equal, -1 for if b is greater, and 1 if a is greater)
+ * \retval -1 for if b is greater
+ * \retval 0 zero for equal
+ * \retval 1 if a is greater
  */
 static int compare_categories(const void *a, const void *b)
 {
Index: res/res_phoneprov.c
===================================================================
--- res/res_phoneprov.c	(revision 103664)
+++ res/res_phoneprov.c	(working copy)
@@ -20,7 +20,7 @@
 
 /*! \file
  *
- * \Phone provisioning application for the asterisk internal http server
+ * \brief Phone provisioning application for the asterisk internal http server
  *
  * \author Matthew Brooks <mbrooks@digium.com>
  * \author Terry Wilson <twilson@digium.com>
